import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';
import { globalRoutes, indexRoutes} from '@/router'

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/index/:index?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'index';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: 'app.views.index.caption',
                info:'',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'index', parameterName: 'index' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/sample/index/index.vue'),
            children: [
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/sf1editview/:sf1editview?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.sf1editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'sf1editview', parameterName: 'sf1editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-sf1-edit-view/ibz5-order-detail-sf1-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/spickupview2/:spickupview2?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.spickupview2.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'spickupview2', parameterName: 'spickupview2' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-spickup-view2/ibz5-sample0003-spickup-view2.vue'),
                },
                {
                    path: 'ibz5hardwares/:ibz5hardware?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.ibz5hardware.views.gridview9.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-hardware-grid-view9/ibz5-hardware-grid-view9.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/sf2editview/:sf2editview?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.sf2editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'sf2editview', parameterName: 'sf2editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-sf2-edit-view/ibz5-order-detail-sf2-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf2editview/:sf2editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf2editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf2editview', parameterName: 'sf2editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf2-edit-view/ibz5-order-sf2-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf1editview/:sf1editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf1editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf1editview', parameterName: 'sf1editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf1-edit-view/ibz5-order-sf1-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf6gridview/:sf6gridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf6gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf6gridview', parameterName: 'sf6gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf6-grid-view/ibz5-order-sf6-grid-view.vue'),
                },
                {
                    path: 'ibz5sample0017s/:ibz5sample0017?/f30editview/:f30editview?',
                    meta: {
                        caption: 'entities.ibz5sample0017.views.f30editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                            { pathName: 'f30editview', parameterName: 'f30editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0017-f30-edit-view/ibz5-sample0017-f30-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf4editview/:sf4editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf4editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf4editview', parameterName: 'sf4editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf4-edit-view/ibz5-order-sf4-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/odsp_d30_wfgridview/:odsp_d30_wfgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.odsp_d30_wfgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'odsp_d30_wfgridview', parameterName: 'odsp_d30_wfgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-odsp-d30-wfgrid-view/ibz5-order-odsp-d30-wfgrid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.ibz5order.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-pickup-view/ibz5-order-pickup-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf4gridview/:sf4gridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf4gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf4gridview', parameterName: 'sf4gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf4-grid-view/ibz5-order-sf4-grid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/linechartview/:linechartview?',
                    meta: {
                        caption: 'entities.ibz5order.views.linechartview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'linechartview', parameterName: 'linechartview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-line-chart-view/ibz5-order-line-chart-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf1gridview/:sf1gridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf1gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf1gridview', parameterName: 'sf1gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf1-grid-view/ibz5-order-sf1-grid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/barchartview/:barchartview?',
                    meta: {
                        caption: 'entities.ibz5order.views.barchartview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'barchartview', parameterName: 'barchartview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-bar-chart-view/ibz5-order-bar-chart-view.vue'),
                },
                {
                    path: 'ibz5sample0001s/:ibz5sample0001?/sf5editview/:sf5editview?',
                    meta: {
                        caption: 'entities.ibz5sample0001.views.sf5editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0001s', parameterName: 'ibz5sample0001' },
                            { pathName: 'sf5editview', parameterName: 'sf5editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0001-sf5-edit-view/ibz5-sample0001-sf5-edit-view.vue'),
                },
                {
                    path: 'ibz5uniproducts/:ibz5uniproduct?/indexpickupdataview/:indexpickupdataview?',
                    meta: {
                        caption: 'entities.ibz5uniproduct.views.indexpickupdataview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                            { pathName: 'indexpickupdataview', parameterName: 'indexpickupdataview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-uniproduct-index-pickup-data-view/ibz5-uniproduct-index-pickup-data-view.vue'),
                },
                {
                    path: 'ibz5softwaresuits/:ibz5softwaresuit?/sgridview/:sgridview?',
                    meta: {
                        caption: 'entities.ibz5softwaresuit.views.sgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5softwaresuits', parameterName: 'ibz5softwaresuit' },
                            { pathName: 'sgridview', parameterName: 'sgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-software-suit-sgrid-view/ibz5-software-suit-sgrid-view.vue'),
                },
                {
                    path: 'ibz5sample0017s/:ibz5sample0017?/f10editview/:f10editview?',
                    meta: {
                        caption: 'entities.ibz5sample0017.views.f10editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                            { pathName: 'f10editview', parameterName: 'f10editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0017-f10-edit-view/ibz5-sample0017-f10-edit-view.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-grid-view/ibz5-order-detail-grid-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/f4treeexpview/:f4treeexpview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.f4treeexpview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'f4treeexpview', parameterName: 'f4treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-f4-tree-exp-view/ibz5-sample0003-f4-tree-exp-view.vue'),
                },
                {
                    path: 'ibz5softwaresuits/:ibz5softwaresuit?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5softwaresuit.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5softwaresuits', parameterName: 'ibz5softwaresuit' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-software-suit-edit-view/ibz5-software-suit-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/odsp_d40_wfgridview/:odsp_d40_wfgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.odsp_d40_wfgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'odsp_d40_wfgridview', parameterName: 'odsp_d40_wfgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-odsp-d40-wfgrid-view/ibz5-order-odsp-d40-wfgrid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/seditview/:seditview?',
                    meta: {
                        caption: 'entities.ibz5order.views.seditview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'seditview', parameterName: 'seditview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sedit-view/ibz5-order-sedit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-edit-view/ibz5-order-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.ibz5order.views.gridview9.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-grid-view9/ibz5-order-grid-view9.vue'),
                },
                {
                    path: 'ibz5uniproducts/:ibz5uniproduct?/indexpickupview/:indexpickupview?',
                    meta: {
                        caption: 'entities.ibz5uniproduct.views.indexpickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                            { pathName: 'indexpickupview', parameterName: 'indexpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-uniproduct-index-pickup-view/ibz5-uniproduct-index-pickup-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/f3treeexpview/:f3treeexpview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.f3treeexpview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'f3treeexpview', parameterName: 'f3treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-f3-tree-exp-view/ibz5-sample0003-f3-tree-exp-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-grid-view/ibz5-order-grid-view.vue'),
                },
                {
                    path: 'ibz5sample0017s/:ibz5sample0017?/formpickupview/:formpickupview?',
                    meta: {
                        caption: 'entities.ibz5sample0017.views.formpickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                            { pathName: 'formpickupview', parameterName: 'formpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0017-form-pickup-view/ibz5-sample0017-form-pickup-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/f9editview/:f9editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.f9editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'f9editview', parameterName: 'f9editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-f9-edit-view/ibz5-order-f9-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/areachartview/:areachartview?',
                    meta: {
                        caption: 'entities.ibz5order.views.areachartview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'areachartview', parameterName: 'areachartview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-area-chart-view/ibz5-order-area-chart-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/seditview3/:seditview3?',
                    meta: {
                        caption: 'entities.ibz5order.views.seditview3.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'seditview3', parameterName: 'seditview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sedit-view3/ibz5-order-sedit-view3.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/f8editview/:f8editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.f8editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'f8editview', parameterName: 'f8editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-f8-edit-view/ibz5-order-f8-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/mpickupview/:mpickupview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.mpickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'mpickupview', parameterName: 'mpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-mpickup-view/ibz5-sample0003-mpickup-view.vue'),
                },
                {
                    path: 'ibz5hardwares/:ibz5hardware?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5hardware.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-hardware-edit-view/ibz5-hardware-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-pickup-grid-view/ibz5-sample0003-pickup-grid-view.vue'),
                },
                {
                    path: 'ibz5uniproducts/:ibz5uniproduct?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5uniproduct.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-uniproduct-edit-view/ibz5-uniproduct-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-grid-view/ibz5-sample0003-grid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/odsp_w10_wfgridview/:odsp_w10_wfgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.odsp_w10_wfgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'odsp_w10_wfgridview', parameterName: 'odsp_w10_wfgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-odsp-w10-wfgrid-view/ibz5-order-odsp-w10-wfgrid-view.vue'),
                },
                {
                    path: 'ibz5sample0001s/:ibz5sample0001?/sf2editview/:sf2editview?',
                    meta: {
                        caption: 'entities.ibz5sample0001.views.sf2editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0001s', parameterName: 'ibz5sample0001' },
                            { pathName: 'sf2editview', parameterName: 'sf2editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0001-sf2-edit-view/ibz5-sample0001-sf2-edit-view.vue'),
                },
                {
                    path: 'ibz5uniproducts/:ibz5uniproduct?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.ibz5uniproduct.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-uniproduct-pickup-view/ibz5-uniproduct-pickup-view.vue'),
                },
                {
                    path: 'ibz5softwaresuits/:ibz5softwaresuit?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.ibz5softwaresuit.views.gridview9.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5softwaresuits', parameterName: 'ibz5softwaresuit' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-software-suit-grid-view9/ibz5-software-suit-grid-view9.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/smeditview9/:smeditview9?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.smeditview9.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'smeditview9', parameterName: 'smeditview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-smedit-view9/ibz5-order-detail-smedit-view9.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf5gridview/:sf5gridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf5gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf5gridview', parameterName: 'sf5gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf5-grid-view/ibz5-order-sf5-grid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf7editview/:sf7editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf7editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf7editview', parameterName: 'sf7editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf7-edit-view/ibz5-order-sf7-edit-view.vue'),
                },
                {
                    path: 'ibz5hardwares/:ibz5hardware?/sgridview/:sgridview?',
                    meta: {
                        caption: 'entities.ibz5hardware.views.sgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                            { pathName: 'sgridview', parameterName: 'sgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-hardware-sgrid-view/ibz5-hardware-sgrid-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/smpickupview2/:smpickupview2?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.smpickupview2.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'smpickupview2', parameterName: 'smpickupview2' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-smpickup-view2/ibz5-sample0003-smpickup-view2.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/f10editview/:f10editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.f10editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'f10editview', parameterName: 'f10editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-f10-edit-view/ibz5-order-f10-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0017s/:ibz5sample0017?/f20editview/:f20editview?',
                    meta: {
                        caption: 'entities.ibz5sample0017.views.f20editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                            { pathName: 'f20editview', parameterName: 'f20editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0017-f20-edit-view/ibz5-sample0017-f20-edit-view.vue'),
                },
                {
                    path: 'ibz5uniproducts/:ibz5uniproduct?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.ibz5uniproduct.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-uniproduct-pickup-grid-view/ibz5-uniproduct-pickup-grid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf20gridview/:sf20gridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf20gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf20gridview', parameterName: 'sf20gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf20-grid-view/ibz5-order-sf20-grid-view.vue'),
                },
                {
                    path: 'ibz5customers/:ibz5customer?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.ibz5customer.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5customers', parameterName: 'ibz5customer' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-customer-pickup-view/ibz5-customer-pickup-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/stabexpview/:stabexpview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.stabexpview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'stabexpview', parameterName: 'stabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-stab-exp-view/ibz5-sample0003-stab-exp-view.vue'),
                },
                {
                    path: 'ibz5hardwares/:ibz5hardware?/indexpickupdataview/:indexpickupdataview?',
                    meta: {
                        caption: 'entities.ibz5hardware.views.indexpickupdataview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                            { pathName: 'indexpickupdataview', parameterName: 'indexpickupdataview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-hardware-index-pickup-data-view/ibz5-hardware-index-pickup-data-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf3gridview/:sf3gridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf3gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf3gridview', parameterName: 'sf3gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf3-grid-view/ibz5-order-sf3-grid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf3editview/:sf3editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf3editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf3editview', parameterName: 'sf3editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf3-edit-view/ibz5-order-sf3-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/f13editview/:f13editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.f13editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'f13editview', parameterName: 'f13editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-f13-edit-view/ibz5-order-f13-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/sf5editview/:sf5editview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.sf5editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'sf5editview', parameterName: 'sf5editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-sf5-edit-view/ibz5-sample0003-sf5-edit-view.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/seditview9/:seditview9?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.seditview9.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'seditview9', parameterName: 'seditview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-sedit-view9/ibz5-order-detail-sedit-view9.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sf15gridview/:sf15gridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sf15gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sf15gridview', parameterName: 'sf15gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sf15-grid-view/ibz5-order-sf15-grid-view.vue'),
                },
                {
                    path: 'ibz5uniproducts/:ibz5uniproduct?/sgridview/:sgridview?',
                    meta: {
                        caption: 'entities.ibz5uniproduct.views.sgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                            { pathName: 'sgridview', parameterName: 'sgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-uniproduct-sgrid-view/ibz5-uniproduct-sgrid-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/streeexpview2/:streeexpview2?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.streeexpview2.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'streeexpview2', parameterName: 'streeexpview2' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-stree-exp-view2/ibz5-sample0003-stree-exp-view2.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sgridview2/:sgridview2?',
                    meta: {
                        caption: 'entities.ibz5order.views.sgridview2.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sgridview2', parameterName: 'sgridview2' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sgrid-view2/ibz5-order-sgrid-view2.vue'),
                },
                {
                    path: 'ibz5uniproducts/:ibz5uniproduct?/gridview9/:gridview9?',
                    meta: {
                        caption: 'entities.ibz5uniproduct.views.gridview9.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                            { pathName: 'gridview9', parameterName: 'gridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-uniproduct-grid-view9/ibz5-uniproduct-grid-view9.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/sf2editview/:sf2editview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.sf2editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'sf2editview', parameterName: 'sf2editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-sf2-edit-view/ibz5-sample0003-sf2-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/f1treeexpview/:f1treeexpview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.f1treeexpview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'f1treeexpview', parameterName: 'f1treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-f1-tree-exp-view/ibz5-sample0003-f1-tree-exp-view.vue'),
                },
                {
                    path: 'ibz5customers/:ibz5customer?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.ibz5customer.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5customers', parameterName: 'ibz5customer' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-customer-pickup-grid-view/ibz5-customer-pickup-grid-view.vue'),
                },
                {
                    path: 'ibz5storages/:ibz5storage?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5storage.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5storages', parameterName: 'ibz5storage' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-storage-edit-view/ibz5-storage-edit-view.vue'),
                },
                {
                    path: 'ibz5cpus/:ibz5cpu?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5cpu.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5cpus', parameterName: 'ibz5cpu' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-cpuedit-view/ibz5-cpuedit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/sgridview/:sgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.sgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'sgridview', parameterName: 'sgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sgrid-view/ibz5-order-sgrid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/wfstartview/:wfstartview?',
                    meta: {
                        caption: 'entities.ibz5order.views.wfstartview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'wfstartview', parameterName: 'wfstartview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-wfstart-view/ibz5-order-wfstart-view.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/sgridview/:sgridview?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.sgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'sgridview', parameterName: 'sgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-sgrid-view/ibz5-order-detail-sgrid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/wfactionview/:wfactionview?',
                    meta: {
                        caption: 'entities.ibz5order.views.wfactionview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'wfactionview', parameterName: 'wfactionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-wfaction-view/ibz5-order-wfaction-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/radarchartview/:radarchartview?',
                    meta: {
                        caption: 'entities.ibz5order.views.radarchartview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'radarchartview', parameterName: 'radarchartview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-radar-chart-view/ibz5-order-radar-chart-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/odsp_w_wfgridview/:odsp_w_wfgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.odsp_w_wfgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'odsp_w_wfgridview', parameterName: 'odsp_w_wfgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-odsp-w-wfgrid-view/ibz5-order-odsp-w-wfgrid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/odsp_d_wfgridview/:odsp_d_wfgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.odsp_d_wfgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'odsp_d_wfgridview', parameterName: 'odsp_d_wfgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-odsp-d-wfgrid-view/ibz5-order-odsp-d-wfgrid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/seditview2/:seditview2?',
                    meta: {
                        caption: 'entities.ibz5order.views.seditview2.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'seditview2', parameterName: 'seditview2' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-sedit-view2/ibz5-order-sedit-view2.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-edit-view/ibz5-order-detail-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-edit-view/ibz5-sample0003-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/piechartview/:piechartview?',
                    meta: {
                        caption: 'entities.ibz5order.views.piechartview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'piechartview', parameterName: 'piechartview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-pie-chart-view/ibz5-order-pie-chart-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/spickuptreeview/:spickuptreeview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.spickuptreeview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'spickuptreeview', parameterName: 'spickuptreeview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-spickup-tree-view/ibz5-sample0003-spickup-tree-view.vue'),
                },
                {
                    path: 'ibz5sample0017s/:ibz5sample0017?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.ibz5sample0017.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0017-grid-view/ibz5-sample0017-grid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/odsp_wfexpview/:odsp_wfexpview?',
                    meta: {
                        caption: 'entities.ibz5order.views.odsp_wfexpview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'odsp_wfexpview', parameterName: 'odsp_wfexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-odsp-wfexp-view/ibz5-order-odsp-wfexp-view.vue'),
                },
                {
                    path: 'ibz5sample0001s/:ibz5sample0001?/sf4editview/:sf4editview?',
                    meta: {
                        caption: 'entities.ibz5sample0001.views.sf4editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0001s', parameterName: 'ibz5sample0001' },
                            { pathName: 'sf4editview', parameterName: 'sf4editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0001-sf4-edit-view/ibz5-sample0001-sf4-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/s2editview/:s2editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.s2editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 's2editview', parameterName: 's2editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-s2-edit-view/ibz5-order-s2-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/odsp_d20_wfgridview/:odsp_d20_wfgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.odsp_d20_wfgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'odsp_d20_wfgridview', parameterName: 'odsp_d20_wfgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-odsp-d20-wfgrid-view/ibz5-order-odsp-d20-wfgrid-view.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/f6gridview/:f6gridview?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.f6gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'f6gridview', parameterName: 'f6gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-f6-grid-view/ibz5-order-detail-f6-grid-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/sf3editview/:sf3editview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.sf3editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'sf3editview', parameterName: 'sf3editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-sf3-edit-view/ibz5-sample0003-sf3-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/sf1editview/:sf1editview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.sf1editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'sf1editview', parameterName: 'sf1editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-sf1-edit-view/ibz5-sample0003-sf1-edit-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-pickup-grid-view/ibz5-order-pickup-grid-view.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/f19editview/:f19editview?',
                    meta: {
                        caption: 'entities.ibz5order.views.f19editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'f19editview', parameterName: 'f19editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-f19-edit-view/ibz5-order-f19-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/f2treeexpview/:f2treeexpview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.f2treeexpview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'f2treeexpview', parameterName: 'f2treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-f2-tree-exp-view/ibz5-sample0003-f2-tree-exp-view.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/f6editview/:f6editview?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.f6editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'f6editview', parameterName: 'f6editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-f6-edit-view/ibz5-order-detail-f6-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/sf4editview/:sf4editview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.sf4editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'sf4editview', parameterName: 'sf4editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-sf4-edit-view/ibz5-sample0003-sf4-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0017s/:ibz5sample0017?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5sample0017.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0017-edit-view/ibz5-sample0017-edit-view.vue'),
                },
                {
                    path: 'ibz5sample0017s/:ibz5sample0017?/formpickupdataview/:formpickupdataview?',
                    meta: {
                        caption: 'entities.ibz5sample0017.views.formpickupdataview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                            { pathName: 'formpickupdataview', parameterName: 'formpickupdataview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0017-form-pickup-data-view/ibz5-sample0017-form-pickup-data-view.vue'),
                },
                {
                    path: 'ibz5customers/:ibz5customer?/editview/:editview?',
                    meta: {
                        caption: 'entities.ibz5customer.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5customers', parameterName: 'ibz5customer' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-customer-edit-view/ibz5-customer-edit-view.vue'),
                },
                {
                    path: 'ibz5orderdetails/:ibz5orderdetail?/sgridview9/:sgridview9?',
                    meta: {
                        caption: 'entities.ibz5orderdetail.views.sgridview9.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                            { pathName: 'sgridview9', parameterName: 'sgridview9' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-detail-sgrid-view9/ibz5-order-detail-sgrid-view9.vue'),
                },
                {
                    path: 'ibz5orders/:ibz5order?/odsp_d10_wfgridview/:odsp_d10_wfgridview?',
                    meta: {
                        caption: 'entities.ibz5order.views.odsp_d10_wfgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                            { pathName: 'odsp_d10_wfgridview', parameterName: 'odsp_d10_wfgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-order-odsp-d10-wfgrid-view/ibz5-order-odsp-d10-wfgrid-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/streeexpview/:streeexpview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.streeexpview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'streeexpview', parameterName: 'streeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-stree-exp-view/ibz5-sample0003-stree-exp-view.vue'),
                },
                {
                    path: 'ibz5sample0003s/:ibz5sample0003?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.ibz5sample0003.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-sample0003-pickup-view/ibz5-sample0003-pickup-view.vue'),
                },
                {
                    path: 'ibz5hardwares/:ibz5hardware?/indexpickupview/:indexpickupview?',
                    meta: {
                        caption: 'entities.ibz5hardware.views.indexpickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                            { pathName: 'indexpickupview', parameterName: 'indexpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/sample/ibz5-hardware-index-pickup-view/ibz5-hardware-index-pickup-view.vue'),
                },
            {
                path: 'appdataredirectview/:appdataredirectview?',
                meta: {
                    caption: 'app.views.appredirectview.caption',
                    info:'',
                    viewType: 'REDIRECTVIEW',
                    parameters: [
                        { pathName: 'appredirectview', parameterName: 'appredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/ungroup/app-redirect-view/app-redirect-view.vue'),
            },
            ...indexRoutes,
            ],
        },
    {
        path: '/apploginview/:apploginview?',
        meta: {
            caption: 'app.views.apploginview.caption',
            info:'',
            parameters: [
                { pathName: 'apploginview', parameterName: 'apploginview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/ungroup/app-login-view/app-login-view.vue'),
    },
    {
        path: '/apppanelview/:apppanelview?',
        meta: {
            caption: 'app.views.apppanelview.caption',
            info:'',
            parameters: [
                { pathName: 'apppanelview', parameterName: 'apppanelview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/ungroup/app-panel-view/app-panel-view.vue'),
    },
    {
        path: '/appstartview/:appstartview?',
        meta: {
            caption: 'app.views.appstartview.caption',
            info:'',
            parameters: [
                { pathName: 'appstartview', parameterName: 'appstartview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/ungroup/app-start-view/app-start-view.vue'),
    },
    {
        path: '/appfileuploadview/:appfileuploadview?',
        meta: {
            caption: 'app.views.appfileuploadview.caption',
            info:'',
            parameters: [
                { pathName: 'appfileuploadview', parameterName: 'appfileuploadview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/ungroup/app-file-upload-view/app-file-upload-view.vue'),
    },
    {
        path: '/applogoutview/:applogoutview?',
        meta: {
            caption: 'app.views.applogoutview.caption',
            info:'',
            parameters: [
                { pathName: 'applogoutview', parameterName: 'applogoutview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/ungroup/app-logout-view/app-logout-view.vue'),
    },
    {
        path: '/appwfstepactorview/:appwfstepactorview?',
        meta: {
            caption: 'app.views.appwfstepactorview.caption',
            info:'',
            parameters: [
                { pathName: 'appwfstepactorview', parameterName: 'appwfstepactorview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/ungroup/app-wfstep-actor-view/app-wfstep-actor-view.vue'),
    },
    {
        path: '/appwfstepdataview/:appwfstepdataview?',
        meta: {
            caption: 'app.views.appwfstepdataview.caption',
            info:'',
            parameters: [
                { pathName: 'appwfstepdataview', parameterName: 'appwfstepdataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/ungroup/app-wfstep-data-view/app-wfstep-data-view.vue'),
    },
            {
                path: '/appdataredirectview/:appdataredirectview?',
                meta: {
                    caption: 'app.views.appredirectview.caption',
                    info:'',
                    viewType: 'REDIRECTVIEW',
                    parameters: [
                        { pathName: 'appredirectview', parameterName: 'appredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/ungroup/app-redirect-view/app-redirect-view.vue'),
            },
    {
        path: '/apppicuploadview/:apppicuploadview?',
        meta: {
            caption: 'app.views.apppicuploadview.caption',
            info:'',
            parameters: [
                { pathName: 'apppicuploadview', parameterName: 'apppicuploadview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/ungroup/app-pic-upload-view/app-pic-upload-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/piechartview/:piechartview?',
        meta: {
            caption: 'entities.ibz5order.views.piechartview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'piechartview', parameterName: 'piechartview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-pie-chart-view/ibz5-order-pie-chart-view.vue'),
    },
    {
        path: '/ibz5sample0017s/:ibz5sample0017?/f20editview/:f20editview?',
        meta: {
            caption: 'entities.ibz5sample0017.views.f20editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                { pathName: 'f20editview', parameterName: 'f20editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0017-f20-edit-view/ibz5-sample0017-f20-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.ibz5order.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-pickup-grid-view/ibz5-order-pickup-grid-view.vue'),
    },
    {
        path: '/ibz5hardwares/:ibz5hardware?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5hardware.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-hardware-edit-view/ibz5-hardware-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/odsp_d10_wfgridview/:odsp_d10_wfgridview?',
        meta: {
            caption: 'entities.ibz5order.views.odsp_d10_wfgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'odsp_d10_wfgridview', parameterName: 'odsp_d10_wfgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-odsp-d10-wfgrid-view/ibz5-order-odsp-d10-wfgrid-view.vue'),
    },
    {
        path: '/ibz5sample0018s/:ibz5sample0018?/gridview/:gridview?',
        meta: {
            caption: 'entities.ibz5sample0018.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0018s', parameterName: 'ibz5sample0018' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0018-grid-view/ibz5-sample0018-grid-view.vue'),
    },
    {
        path: '/ibz5hardwares/:ibz5hardware?/indexpickupdataview/:indexpickupdataview?',
        meta: {
            caption: 'entities.ibz5hardware.views.indexpickupdataview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                { pathName: 'indexpickupdataview', parameterName: 'indexpickupdataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-hardware-index-pickup-data-view/ibz5-hardware-index-pickup-data-view.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/sgridview9/:sgridview9?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.sgridview9.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'sgridview9', parameterName: 'sgridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-sgrid-view9/ibz5-order-detail-sgrid-view9.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/odsp_d30_wfgridview/:odsp_d30_wfgridview?',
        meta: {
            caption: 'entities.ibz5order.views.odsp_d30_wfgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'odsp_d30_wfgridview', parameterName: 'odsp_d30_wfgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-odsp-d30-wfgrid-view/ibz5-order-odsp-d30-wfgrid-view.vue'),
    },
    {
        path: '/ibz5cpus/:ibz5cpu?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5cpu.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5cpus', parameterName: 'ibz5cpu' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-cpuedit-view/ibz5-cpuedit-view.vue'),
    },
    {
        path: '/ibz5sample0017s/:ibz5sample0017?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5sample0017.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0017-edit-view/ibz5-sample0017-edit-view.vue'),
    },
    {
        path: '/ibz5uniproducts/:ibz5uniproduct?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.ibz5uniproduct.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-uniproduct-pickup-grid-view/ibz5-uniproduct-pickup-grid-view.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/sf2editview/:sf2editview?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.sf2editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'sf2editview', parameterName: 'sf2editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-sf2-edit-view/ibz5-order-detail-sf2-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.ibz5order.views.gridview9.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-grid-view9/ibz5-order-grid-view9.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/seditview9/:seditview9?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.seditview9.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'seditview9', parameterName: 'seditview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-sedit-view9/ibz5-order-detail-sedit-view9.vue'),
    },
    {
        path: '/ibz5uniproducts/:ibz5uniproduct?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.ibz5uniproduct.views.gridview9.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-uniproduct-grid-view9/ibz5-uniproduct-grid-view9.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf1editview/:sf1editview?',
        meta: {
            caption: 'entities.ibz5order.views.sf1editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf1editview', parameterName: 'sf1editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf1-edit-view/ibz5-order-sf1-edit-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/sf3editview/:sf3editview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.sf3editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'sf3editview', parameterName: 'sf3editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-sf3-edit-view/ibz5-sample0003-sf3-edit-view.vue'),
    },
    {
        path: '/ibz5hardwares/:ibz5hardware?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.ibz5hardware.views.gridview9.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-hardware-grid-view9/ibz5-hardware-grid-view9.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf1gridview/:sf1gridview?',
        meta: {
            caption: 'entities.ibz5order.views.sf1gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf1gridview', parameterName: 'sf1gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf1-grid-view/ibz5-order-sf1-grid-view.vue'),
    },
    {
        path: '/ibz5sample0017s/:ibz5sample0017?/formpickupdataview/:formpickupdataview?',
        meta: {
            caption: 'entities.ibz5sample0017.views.formpickupdataview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                { pathName: 'formpickupdataview', parameterName: 'formpickupdataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0017-form-pickup-data-view/ibz5-sample0017-form-pickup-data-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/mpickupview/:mpickupview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.mpickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'mpickupview', parameterName: 'mpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-mpickup-view/ibz5-sample0003-mpickup-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/gridview/:gridview?',
        meta: {
            caption: 'entities.ibz5order.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-grid-view/ibz5-order-grid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/f8editview/:f8editview?',
        meta: {
            caption: 'entities.ibz5order.views.f8editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'f8editview', parameterName: 'f8editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-f8-edit-view/ibz5-order-f8-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/odsp_d_wfgridview/:odsp_d_wfgridview?',
        meta: {
            caption: 'entities.ibz5order.views.odsp_d_wfgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'odsp_d_wfgridview', parameterName: 'odsp_d_wfgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-odsp-d-wfgrid-view/ibz5-order-odsp-d-wfgrid-view.vue'),
    },
    {
        path: '/ibz5uniproducts/:ibz5uniproduct?/indexpickupview/:indexpickupview?',
        meta: {
            caption: 'entities.ibz5uniproduct.views.indexpickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                { pathName: 'indexpickupview', parameterName: 'indexpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-uniproduct-index-pickup-view/ibz5-uniproduct-index-pickup-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/gridview/:gridview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-grid-view/ibz5-sample0003-grid-view.vue'),
    },
    {
        path: '/ibz5sample0017s/:ibz5sample0017?/f10editview/:f10editview?',
        meta: {
            caption: 'entities.ibz5sample0017.views.f10editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                { pathName: 'f10editview', parameterName: 'f10editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0017-f10-edit-view/ibz5-sample0017-f10-edit-view.vue'),
    },
    {
        path: '/ibz5uniproducts/:ibz5uniproduct?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.ibz5uniproduct.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-uniproduct-pickup-view/ibz5-uniproduct-pickup-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5order.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-edit-view/ibz5-order-edit-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/stabexpview/:stabexpview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.stabexpview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'stabexpview', parameterName: 'stabexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-stab-exp-view/ibz5-sample0003-stab-exp-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/spickuptreeview/:spickuptreeview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.spickuptreeview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'spickuptreeview', parameterName: 'spickuptreeview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-spickup-tree-view/ibz5-sample0003-spickup-tree-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sgridview/:sgridview?',
        meta: {
            caption: 'entities.ibz5order.views.sgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sgridview', parameterName: 'sgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sgrid-view/ibz5-order-sgrid-view.vue'),
    },
    {
        path: '/ibz5sample0001s/:ibz5sample0001?/sf4editview/:sf4editview?',
        meta: {
            caption: 'entities.ibz5sample0001.views.sf4editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0001s', parameterName: 'ibz5sample0001' },
                { pathName: 'sf4editview', parameterName: 'sf4editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0001-sf4-edit-view/ibz5-sample0001-sf4-edit-view.vue'),
    },
    {
        path: '/ibz5softwaresuits/:ibz5softwaresuit?/sgridview/:sgridview?',
        meta: {
            caption: 'entities.ibz5softwaresuit.views.sgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5softwaresuits', parameterName: 'ibz5softwaresuit' },
                { pathName: 'sgridview', parameterName: 'sgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-software-suit-sgrid-view/ibz5-software-suit-sgrid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/odsp_d20_wfgridview/:odsp_d20_wfgridview?',
        meta: {
            caption: 'entities.ibz5order.views.odsp_d20_wfgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'odsp_d20_wfgridview', parameterName: 'odsp_d20_wfgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-odsp-d20-wfgrid-view/ibz5-order-odsp-d20-wfgrid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf4gridview/:sf4gridview?',
        meta: {
            caption: 'entities.ibz5order.views.sf4gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf4gridview', parameterName: 'sf4gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf4-grid-view/ibz5-order-sf4-grid-view.vue'),
    },
    {
        path: '/ibz5sample0014s/:ibz5sample0014?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5sample0014.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0014s', parameterName: 'ibz5sample0014' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0014-edit-view/ibz5-sample0014-edit-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-pickup-grid-view/ibz5-sample0003-pickup-grid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/radarchartview/:radarchartview?',
        meta: {
            caption: 'entities.ibz5order.views.radarchartview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'radarchartview', parameterName: 'radarchartview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-radar-chart-view/ibz5-order-radar-chart-view.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/gridview/:gridview?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-grid-view/ibz5-order-detail-grid-view.vue'),
    },
    {
        path: '/ibz5softwaresuits/:ibz5softwaresuit?/gridview9/:gridview9?',
        meta: {
            caption: 'entities.ibz5softwaresuit.views.gridview9.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5softwaresuits', parameterName: 'ibz5softwaresuit' },
                { pathName: 'gridview9', parameterName: 'gridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-software-suit-grid-view9/ibz5-software-suit-grid-view9.vue'),
    },
    {
        path: '/ibz5uniproducts/:ibz5uniproduct?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5uniproduct.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-uniproduct-edit-view/ibz5-uniproduct-edit-view.vue'),
    },
    {
        path: '/ibz5hardwares/:ibz5hardware?/indexpickupview/:indexpickupview?',
        meta: {
            caption: 'entities.ibz5hardware.views.indexpickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                { pathName: 'indexpickupview', parameterName: 'indexpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-hardware-index-pickup-view/ibz5-hardware-index-pickup-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf5gridview/:sf5gridview?',
        meta: {
            caption: 'entities.ibz5order.views.sf5gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf5gridview', parameterName: 'sf5gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf5-grid-view/ibz5-order-sf5-grid-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/smpickupview2/:smpickupview2?',
        meta: {
            caption: 'entities.ibz5sample0003.views.smpickupview2.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'smpickupview2', parameterName: 'smpickupview2' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-smpickup-view2/ibz5-sample0003-smpickup-view2.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/f6editview/:f6editview?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.f6editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'f6editview', parameterName: 'f6editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-f6-edit-view/ibz5-order-detail-f6-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/f13editview/:f13editview?',
        meta: {
            caption: 'entities.ibz5order.views.f13editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'f13editview', parameterName: 'f13editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-f13-edit-view/ibz5-order-f13-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/seditview2/:seditview2?',
        meta: {
            caption: 'entities.ibz5order.views.seditview2.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'seditview2', parameterName: 'seditview2' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sedit-view2/ibz5-order-sedit-view2.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sgridview2/:sgridview2?',
        meta: {
            caption: 'entities.ibz5order.views.sgridview2.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sgridview2', parameterName: 'sgridview2' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sgrid-view2/ibz5-order-sgrid-view2.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/wfstartview/:wfstartview?',
        meta: {
            caption: 'entities.ibz5order.views.wfstartview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'wfstartview', parameterName: 'wfstartview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-wfstart-view/ibz5-order-wfstart-view.vue'),
    },
    {
        path: '/ibz5uniproducts/:ibz5uniproduct?/sgridview/:sgridview?',
        meta: {
            caption: 'entities.ibz5uniproduct.views.sgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                { pathName: 'sgridview', parameterName: 'sgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-uniproduct-sgrid-view/ibz5-uniproduct-sgrid-view.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/smeditview9/:smeditview9?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.smeditview9.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'smeditview9', parameterName: 'smeditview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-smedit-view9/ibz5-order-detail-smedit-view9.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/s2editview/:s2editview?',
        meta: {
            caption: 'entities.ibz5order.views.s2editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 's2editview', parameterName: 's2editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-s2-edit-view/ibz5-order-s2-edit-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/sf1editview/:sf1editview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.sf1editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'sf1editview', parameterName: 'sf1editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-sf1-edit-view/ibz5-sample0003-sf1-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/seditview/:seditview?',
        meta: {
            caption: 'entities.ibz5order.views.seditview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'seditview', parameterName: 'seditview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sedit-view/ibz5-order-sedit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/odsp_wfexpview/:odsp_wfexpview?',
        meta: {
            caption: 'entities.ibz5order.views.odsp_wfexpview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'odsp_wfexpview', parameterName: 'odsp_wfexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-odsp-wfexp-view/ibz5-order-odsp-wfexp-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-edit-view/ibz5-sample0003-edit-view.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/sf1editview/:sf1editview?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.sf1editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'sf1editview', parameterName: 'sf1editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-sf1-edit-view/ibz5-order-detail-sf1-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/f10editview/:f10editview?',
        meta: {
            caption: 'entities.ibz5order.views.f10editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'f10editview', parameterName: 'f10editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-f10-edit-view/ibz5-order-f10-edit-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/sf5editview/:sf5editview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.sf5editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'sf5editview', parameterName: 'sf5editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-sf5-edit-view/ibz5-sample0003-sf5-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/odsp_w10_wfgridview/:odsp_w10_wfgridview?',
        meta: {
            caption: 'entities.ibz5order.views.odsp_w10_wfgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'odsp_w10_wfgridview', parameterName: 'odsp_w10_wfgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-odsp-w10-wfgrid-view/ibz5-order-odsp-w10-wfgrid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf4editview/:sf4editview?',
        meta: {
            caption: 'entities.ibz5order.views.sf4editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf4editview', parameterName: 'sf4editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf4-edit-view/ibz5-order-sf4-edit-view.vue'),
    },
    {
        path: '/ibz5sample0017s/:ibz5sample0017?/f30editview/:f30editview?',
        meta: {
            caption: 'entities.ibz5sample0017.views.f30editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                { pathName: 'f30editview', parameterName: 'f30editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0017-f30-edit-view/ibz5-sample0017-f30-edit-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/f4treeexpview/:f4treeexpview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.f4treeexpview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'f4treeexpview', parameterName: 'f4treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-f4-tree-exp-view/ibz5-sample0003-f4-tree-exp-view.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-edit-view/ibz5-order-detail-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/seditview3/:seditview3?',
        meta: {
            caption: 'entities.ibz5order.views.seditview3.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'seditview3', parameterName: 'seditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sedit-view3/ibz5-order-sedit-view3.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/odsp_w_wfgridview/:odsp_w_wfgridview?',
        meta: {
            caption: 'entities.ibz5order.views.odsp_w_wfgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'odsp_w_wfgridview', parameterName: 'odsp_w_wfgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-odsp-w-wfgrid-view/ibz5-order-odsp-w-wfgrid-view.vue'),
    },
    {
        path: '/ibz5sample0018s/:ibz5sample0018?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5sample0018.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0018s', parameterName: 'ibz5sample0018' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0018-edit-view/ibz5-sample0018-edit-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/streeexpview/:streeexpview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.streeexpview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'streeexpview', parameterName: 'streeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-stree-exp-view/ibz5-sample0003-stree-exp-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/f2treeexpview/:f2treeexpview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.f2treeexpview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'f2treeexpview', parameterName: 'f2treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-f2-tree-exp-view/ibz5-sample0003-f2-tree-exp-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.ibz5order.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-pickup-view/ibz5-order-pickup-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf7editview/:sf7editview?',
        meta: {
            caption: 'entities.ibz5order.views.sf7editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf7editview', parameterName: 'sf7editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf7-edit-view/ibz5-order-sf7-edit-view.vue'),
    },
    {
        path: '/ibz5customers/:ibz5customer?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.ibz5customer.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5customers', parameterName: 'ibz5customer' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-customer-pickup-view/ibz5-customer-pickup-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf6gridview/:sf6gridview?',
        meta: {
            caption: 'entities.ibz5order.views.sf6gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf6gridview', parameterName: 'sf6gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf6-grid-view/ibz5-order-sf6-grid-view.vue'),
    },
    {
        path: '/ibz5softwaresuits/:ibz5softwaresuit?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5softwaresuit.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5softwaresuits', parameterName: 'ibz5softwaresuit' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-software-suit-edit-view/ibz5-software-suit-edit-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/sf2editview/:sf2editview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.sf2editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'sf2editview', parameterName: 'sf2editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-sf2-edit-view/ibz5-sample0003-sf2-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/linechartview/:linechartview?',
        meta: {
            caption: 'entities.ibz5order.views.linechartview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'linechartview', parameterName: 'linechartview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-line-chart-view/ibz5-order-line-chart-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/barchartview/:barchartview?',
        meta: {
            caption: 'entities.ibz5order.views.barchartview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'barchartview', parameterName: 'barchartview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-bar-chart-view/ibz5-order-bar-chart-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/wfactionview/:wfactionview?',
        meta: {
            caption: 'entities.ibz5order.views.wfactionview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'wfactionview', parameterName: 'wfactionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-wfaction-view/ibz5-order-wfaction-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf15gridview/:sf15gridview?',
        meta: {
            caption: 'entities.ibz5order.views.sf15gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf15gridview', parameterName: 'sf15gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf15-grid-view/ibz5-order-sf15-grid-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/spickupview2/:spickupview2?',
        meta: {
            caption: 'entities.ibz5sample0003.views.spickupview2.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'spickupview2', parameterName: 'spickupview2' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-spickup-view2/ibz5-sample0003-spickup-view2.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf2editview/:sf2editview?',
        meta: {
            caption: 'entities.ibz5order.views.sf2editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf2editview', parameterName: 'sf2editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf2-edit-view/ibz5-order-sf2-edit-view.vue'),
    },
    {
        path: '/ibz5sample0014s/:ibz5sample0014?/gridview/:gridview?',
        meta: {
            caption: 'entities.ibz5sample0014.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0014s', parameterName: 'ibz5sample0014' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0014-grid-view/ibz5-sample0014-grid-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/f3treeexpview/:f3treeexpview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.f3treeexpview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'f3treeexpview', parameterName: 'f3treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-f3-tree-exp-view/ibz5-sample0003-f3-tree-exp-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/f19editview/:f19editview?',
        meta: {
            caption: 'entities.ibz5order.views.f19editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'f19editview', parameterName: 'f19editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-f19-edit-view/ibz5-order-f19-edit-view.vue'),
    },
    {
        path: '/ibz5customers/:ibz5customer?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5customer.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5customers', parameterName: 'ibz5customer' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-customer-edit-view/ibz5-customer-edit-view.vue'),
    },
    {
        path: '/ibz5storages/:ibz5storage?/editview/:editview?',
        meta: {
            caption: 'entities.ibz5storage.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5storages', parameterName: 'ibz5storage' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-storage-edit-view/ibz5-storage-edit-view.vue'),
    },
    {
        path: '/ibz5uniproducts/:ibz5uniproduct?/indexpickupdataview/:indexpickupdataview?',
        meta: {
            caption: 'entities.ibz5uniproduct.views.indexpickupdataview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5uniproducts', parameterName: 'ibz5uniproduct' },
                { pathName: 'indexpickupdataview', parameterName: 'indexpickupdataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-uniproduct-index-pickup-data-view/ibz5-uniproduct-index-pickup-data-view.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/f6gridview/:f6gridview?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.f6gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'f6gridview', parameterName: 'f6gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-f6-grid-view/ibz5-order-detail-f6-grid-view.vue'),
    },
    {
        path: '/ibz5sample0001s/:ibz5sample0001?/sf2editview/:sf2editview?',
        meta: {
            caption: 'entities.ibz5sample0001.views.sf2editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0001s', parameterName: 'ibz5sample0001' },
                { pathName: 'sf2editview', parameterName: 'sf2editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0001-sf2-edit-view/ibz5-sample0001-sf2-edit-view.vue'),
    },
    {
        path: '/ibz5sample0017s/:ibz5sample0017?/gridview/:gridview?',
        meta: {
            caption: 'entities.ibz5sample0017.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0017-grid-view/ibz5-sample0017-grid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/areachartview/:areachartview?',
        meta: {
            caption: 'entities.ibz5order.views.areachartview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'areachartview', parameterName: 'areachartview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-area-chart-view/ibz5-order-area-chart-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/f1treeexpview/:f1treeexpview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.f1treeexpview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'f1treeexpview', parameterName: 'f1treeexpview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-f1-tree-exp-view/ibz5-sample0003-f1-tree-exp-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/streeexpview2/:streeexpview2?',
        meta: {
            caption: 'entities.ibz5sample0003.views.streeexpview2.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'streeexpview2', parameterName: 'streeexpview2' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-stree-exp-view2/ibz5-sample0003-stree-exp-view2.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/sf4editview/:sf4editview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.sf4editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'sf4editview', parameterName: 'sf4editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-sf4-edit-view/ibz5-sample0003-sf4-edit-view.vue'),
    },
    {
        path: '/ibz5sample0017s/:ibz5sample0017?/formpickupview/:formpickupview?',
        meta: {
            caption: 'entities.ibz5sample0017.views.formpickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0017s', parameterName: 'ibz5sample0017' },
                { pathName: 'formpickupview', parameterName: 'formpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0017-form-pickup-view/ibz5-sample0017-form-pickup-view.vue'),
    },
    {
        path: '/ibz5sample0003s/:ibz5sample0003?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.ibz5sample0003.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0003s', parameterName: 'ibz5sample0003' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0003-pickup-view/ibz5-sample0003-pickup-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf20gridview/:sf20gridview?',
        meta: {
            caption: 'entities.ibz5order.views.sf20gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf20gridview', parameterName: 'sf20gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf20-grid-view/ibz5-order-sf20-grid-view.vue'),
    },
    {
        path: '/ibz5customers/:ibz5customer?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.ibz5customer.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5customers', parameterName: 'ibz5customer' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-customer-pickup-grid-view/ibz5-customer-pickup-grid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf3editview/:sf3editview?',
        meta: {
            caption: 'entities.ibz5order.views.sf3editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf3editview', parameterName: 'sf3editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf3-edit-view/ibz5-order-sf3-edit-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/odsp_d40_wfgridview/:odsp_d40_wfgridview?',
        meta: {
            caption: 'entities.ibz5order.views.odsp_d40_wfgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'odsp_d40_wfgridview', parameterName: 'odsp_d40_wfgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-odsp-d40-wfgrid-view/ibz5-order-odsp-d40-wfgrid-view.vue'),
    },
    {
        path: '/ibz5hardwares/:ibz5hardware?/sgridview/:sgridview?',
        meta: {
            caption: 'entities.ibz5hardware.views.sgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5hardwares', parameterName: 'ibz5hardware' },
                { pathName: 'sgridview', parameterName: 'sgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-hardware-sgrid-view/ibz5-hardware-sgrid-view.vue'),
    },
    {
        path: '/ibz5sample0001s/:ibz5sample0001?/sf5editview/:sf5editview?',
        meta: {
            caption: 'entities.ibz5sample0001.views.sf5editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5sample0001s', parameterName: 'ibz5sample0001' },
                { pathName: 'sf5editview', parameterName: 'sf5editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-sample0001-sf5-edit-view/ibz5-sample0001-sf5-edit-view.vue'),
    },
    {
        path: '/ibz5orderdetails/:ibz5orderdetail?/sgridview/:sgridview?',
        meta: {
            caption: 'entities.ibz5orderdetail.views.sgridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orderdetails', parameterName: 'ibz5orderdetail' },
                { pathName: 'sgridview', parameterName: 'sgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-detail-sgrid-view/ibz5-order-detail-sgrid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/sf3gridview/:sf3gridview?',
        meta: {
            caption: 'entities.ibz5order.views.sf3gridview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'sf3gridview', parameterName: 'sf3gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-sf3-grid-view/ibz5-order-sf3-grid-view.vue'),
    },
    {
        path: '/ibz5orders/:ibz5order?/f9editview/:f9editview?',
        meta: {
            caption: 'entities.ibz5order.views.f9editview.caption',
            info:'',
            parameters: [
                { pathName: 'ibz5orders', parameterName: 'ibz5order' },
                { pathName: 'f9editview', parameterName: 'f9editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/sample/ibz5-order-f9-edit-view/ibz5-order-f9-edit-view.vue'),
    },
        ...globalRoutes,
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/lock',
            name: 'lock',
            meta: {  
                caption: '锁屏',
                viewType: 'lock',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                next();
            },
            component: () => import('@components/app-lock/app-lock.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'index'
        },
    ],
});
// 解决路由跳转路由重复时报错
const originalPush = Router.prototype.push
Router.prototype.push = function push(location: any) {
    let result: any = originalPush.call(this, location);
    return result.catch((err: any) => err);
}
export default router;
